function [loc_cov_month] = get_mtr_pp_covari_attrib_month(bins, COVARIATES_ATTRIB, ...
        COVARIATES_WIND_GAUSS)
%
%   Get month covariates
%
% -------
% INPUTS:
%
%   bins                    : time bins
%   COVARIATES_ATTRIB       : see the config file.
%   COVARIATES_WIND_GAUSS   : see the config file.
%
% --------
% OUTPUTS:
%
%   loc_cov_month          : covariate matrix for year
%
% -------------
%
% Gunhee Kim

% (2) Month Covariates
if strfind(COVARIATES_ATTRIB,'m'),
    % number of bins
    num_bin = length(bins.tick) ;

    % (2.1) Impulse filtering
    if COVARIATES_WIND_GAUSS==0,
        % get monthly co-variance matrix using an impulse filter
        date_month = fn_time_month(bins.tick) ;
        loc_cov_month = sparse(1:num_bin, date_month, ones(1,num_bin), ...
            num_bin, 12);
        clear date_month ;
        dimCov(2) = size(loc_cov_month, 2) ;
    % (2.2) Gaussian filtering
    else
        % get monthly co-variance matrix using a gaussian filter
        % gauss filter
        alpha = 1 ;
        RANGE_MONTH = 2 ;
        gau_filt_val = exp(-alpha*(([0:6]).^2)) ;
        gau_filt_val = gau_filt_val(2:RANGE_MONTH+1) ;

        range_month = zeros(12, 2*RANGE_MONTH) ;
        range_weight = [gau_filt_val(RANGE_MONTH:-1:1) gau_filt_val(1:RANGE_MONTH)] ;
        for i=1:12,
            range_month(i,:) = [(i-RANGE_MONTH):(i-1), (i+1):(i+RANGE_MONTH)]  ;
            range_month(i,:) = mod(range_month(i,:)-1,12)+1;
        end

        date_month = fn_time_month(bins.tick) ;
        date_ngh = range_month(date_month,:) ;

        r_ind = repmat([1:num_bin]',[1 2*RANGE_MONTH+1]) ;
        c_ind = [date_month' date_ngh] ;
        v_val = [ones(num_bin,1) repmat(range_weight, [num_bin 1])];

        loc_cov_month = sparse(r_ind, c_ind, v_val, num_bin, 12);
        clear r_ind c_ind v_val date_ngh ;

        dimCov(2) = size(loc_cov_month, 2) ;
    end
else
    loc_cov_month = [] ;
end

end

